@@ -7,11 +7,11 @@ from netbox.api.viewsets import NetBoxModelViewSet
 from netbox_storage.api.serializers import (
     DriveSerializer,
     FilesystemSerializer, PartitionSerializer, PhysicalVolumeSerializer, LogicalVolumeSerializer,
-    VolumeGroupSerializer,
+    VolumeGroupSerializer, LinuxVolumeSerializer
 )
 from netbox_storage.filters import DriveFilter, FilesystemFilter, \
-    PartitionFilter, PhysicalVolumeFilter, LogicalVolumeFilter, VolumeGroupFilter
-from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, LogicalVolume, VolumeGroup
+    PartitionFilter, PhysicalVolumeFilter, LogicalVolumeFilter, VolumeGroupFilter, LinuxVolumeFilter
+from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, LogicalVolume, VolumeGroup, LinuxVolume
 
 
 class NetboxStorageRootView(APIRootView):
@@ -93,3 +93,15 @@ class VolumeGroupViewSet(NetBoxModelViewSet):
         volumegroup = VolumeGroup.objects.filter(volumegroup__id=pk)
         serializer = VolumeGroupSerializer(volumegroup, many=True, context={"request": request})
         return Response(serializer.data)
+
+
+class LinuxVolumeViewSet(NetBoxModelViewSet):
+    queryset = LinuxVolume.objects.all()
+    serializer_class = LinuxVolumeSerializer
+    filterset_class = LinuxVolumeFilter
+
+    @action(detail=True, methods=["get"])
+    def linuxvolume(self, request, pk=None):
+        linuxvolume = LinuxVolume.objects.filter(linuxvolume__id=pk)
+        serializer = LinuxVolumeSerializer(linuxvolume, many=True, context={"request": request})
+        return Response(serializer.data)
