@@ -152,7 +152,8 @@ urlpatterns = [
         name="volumegroup_changelog",
         kwargs={"model": VolumeGroup},
     ),
-    path("volumegroup/<int:pk>/physicalvolume/", VolumeGroupPhysicalVolumeListView.as_view(), name="vg_physicalvolumes"),
+    path("volumegroup/<int:pk>/physicalvolume/", VolumeGroupPhysicalVolumeListView.as_view(),
+         name="volumegroup_physicalvolumes"),
     #
     # LogicalVolume urls
     #
