@@ -1,6 +1,6 @@
 from netbox.views import generic
 
-from netbox_storage.filters import VolumeGroupFilter
+from netbox_storage.filters import VolumeGroupFilter, PhysicalVolumeFilter
 from netbox_storage.forms import (
     VolumeGroupImportForm,
     VolumeGroupFilterForm,
@@ -8,8 +8,9 @@ from netbox_storage.forms import (
     VolumeGroupBulkEditForm
 )
 
-from netbox_storage.models import VolumeGroup
-from netbox_storage.tables import VolumeGroupTable
+from netbox_storage.models import VolumeGroup, PhysicalVolume
+from netbox_storage.tables import VolumeGroupTable, PhysicalVolumeTable
+from utilities.views import register_model_view, ViewTab
 
 
 class VolumeGroupListView(generic.ObjectListView):
@@ -55,3 +56,24 @@ class VolumeGroupBulkEditView(generic.BulkEditView):
 class VolumeGroupBulkDeleteView(generic.BulkDeleteView):
     queryset = VolumeGroup.objects.all()
     table = VolumeGroupTable
+
+
+@register_model_view(VolumeGroup, "physicalvolumes")
+class VolumeGroupPhysicalVolumeListView(generic.ObjectChildrenView):
+    queryset = VolumeGroup.objects.all()
+    child_model = PhysicalVolume
+    table = PhysicalVolumeTable
+    filterset = PhysicalVolumeFilter
+    template_name = "netbox_storage/volumegroup/physicalvolume.html"
+    hide_if_empty = False
+
+    tab = ViewTab(
+        label="Physical Volumes",
+        badge=lambda obj: obj.physical_volume_count(),
+        hide_if_empty=False,
+    )
+
+    def get_children(self, request, parent):
+        return PhysicalVolume.objects.filter(
+            vg=parent
+        )
